==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/industrial_protocol_docs/am64x/ethercat_slave/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "EtherCAT Slave", "index.html", [
    [ "Introduction", "index.html", null ],
    [ "Release Notes", "releasenotes.html", [
      [ "Overview", "releasenotes.html#releasenotesoverview", null ],
      [ "Licensing", "releasenotes.html#releasenoteslicensing", null ],
      [ "Release Version 1.04.01", "releasenotes.html#version_release10401", null ],
      [ "Release Version 1.04.00", "releasenotes.html#version_release10400", null ],
      [ "Release Version 1.03.01", "releasenotes.html#version_release10301", null ],
      [ "Release Version 1.03.00", "releasenotes.html#version_release10300", null ],
      [ "Release Version 1.02.03", "releasenotes.html#version_release10203", null ],
      [ "Release Version 1.02.00", "releasenotes.html#version_release10200", null ],
      [ "Release Version 1.01.01", "releasenotes.html#version_release10101", null ],
      [ "Release Version 1.01.00", "releasenotes.html#version_release", null ]
    ] ],
    [ "General Information", "generalinformation.html", [
      [ "Disclaimer", "disclaimer.html", null ],
      [ "Target Audience", "targetaudience.html", null ],
      [ "Delivery Content", "deliverycontent.html", null ],
      [ "Supported Functionality", "functionality.html", null ],
      [ "Customer Service", "customerservice.html", null ],
      [ "References", "references.html", null ],
      [ "Abbreviations and Definitions", "abbreviations.html", null ]
    ] ],
    [ "Quickstart - EtherCAT Device", "page_quickstart.html", [
      [ "Setup", "page_quickstart_installation.html", [
        [ "Software Installation", "page_quickstart_installation.html#qs_installation_software", null ],
        [ "Connect the Evaluation Board", "page_quickstart_installation.html#qs_installation_connect", null ]
      ] ],
      [ "Simple EtherCAT Example", "example1.html", null ],
      [ "CiA402 EtherCAT Example", "example2.html", null ]
    ] ],
    [ "Connect to PLC - CODESYS on RevPi", "plc_codesys.html", null ],
    [ "API Reference", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Related Information", "usergroup0.html", [
      [ "KUNBUS GmbH", "^http://www.kunbus.com", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"abbreviations.html",
"group___ci_a402_gac6450ce16e670b7298f70c66513d2cb7.html#gac6450ce16e670b7298f70c66513d2cb7",
"group___e_c___a_p_i___s_l_v___e_r_r_o_r___c_o_d_e_s_ga022716c308f5d5bd84876c11d568a77e.html#gga022716c308f5d5bd84876c11d568a77eab24388b81609242faa9d56f8e6a3f682",
"group___so_e_ga6456f7fd30a7229035e3f880f6fe2fb3.html#ga6456f7fd30a7229035e3f880f6fe2fb3",
"structkb_ec_cfg___un_parse_collection_a56d9ade30162814f49a4f10adbcf7117.html#a56d9ade30162814f49a4f10adbcf7117"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mcu_plus_sdk_am64x_08_01_00_36_docs_only.tar.xz: mcu_plus_sdk_am64x_08_01_00_36_docs_only/docs/industrial_protocol_docs/am64x/ethercat_slave/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "EtherCAT Slave", "index.html", [
    [ "Introduction", "index.html", null ],
    [ "Datasheet", "ethercat_datasheet.html", null ],
    [ "Release Notes", "releasenotes.html", [
      [ "Known Issues", "known_issues.html", null ],
      [ "Overview", "releasenotes.html#releasenotesoverview", null ],
      [ "Licensing", "releasenotes.html#releasenoteslicensing", null ],
      [ "Release Version 1.04.06", "releasenotes.html#version_release10406", null ],
      [ "Release Version 1.04.05", "releasenotes.html#version_release10405", null ],
      [ "Release Version 1.04.04", "releasenotes.html#version_release10404", null ],
      [ "Release Version 1.04.03", "releasenotes.html#version_release10403", null ],
      [ "Release Version 1.04.02", "releasenotes.html#version_release10402", null ],
      [ "Release Version 1.04.01", "releasenotes.html#version_release10401", null ],
      [ "Release Version 1.04.00", "releasenotes.html#version_release10400", null ],
      [ "Release Version 1.03.01", "releasenotes.html#version_release10301", null ],
      [ "Release Version 1.03.00", "releasenotes.html#version_release10300", null ],
      [ "Release Version 1.02.03", "releasenotes.html#version_release10203", null ],
      [ "Release Version 1.02.00", "releasenotes.html#version_release10200", null ],
      [ "Release Version 1.01.01", "releasenotes.html#version_release10101", null ],
      [ "Release Version 1.01.00", "releasenotes.html#version_release", null ]
    ] ],
    [ "General Information", "generalinformation.html", [
      [ "Disclaimer", "disclaimer.html", null ],
      [ "Target Audience", "targetaudience.html", null ],
      [ "Delivery Content", "deliverycontent.html", null ],
      [ "Customer Service", "customerservice.html", null ],
      [ "References", "references.html", null ],
      [ "Abbreviations and Definitions", "abbreviations.html", null ]
    ] ],
    [ "Quickstart - EtherCAT Device", "page_quickstart.html", [
      [ "Setup", "page_quickstart_installation.html", [
        [ "Software Installation", "page_quickstart_installation.html#qs_installation_software", null ],
        [ "Connect the Evaluation Board", "page_quickstart_installation.html#qs_installation_connect", null ],
        [ "Steps to Run the Example", "page_quickstart_installation.html#qs_steps_to_run_example", null ]
      ] ],
      [ "Simple EtherCAT Example", "example1.html", null ],
      [ "CiA402 EtherCAT Example", "example2.html", null ]
    ] ],
    [ "Connect to PLC - CODESYS", "plc_codesys.html", [
      [ "KUNBUS Revolution Pi", "plc_codesys_revpi.html", null ],
      [ "SITARA AM64x Processor", "plc_codesys_am64x.html", null ]
    ] ],
    [ "Connect to PLC - TwinCAT3", "simple_demo_in_twincat3.html", null ],
    [ "API Reference", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Related Information", "usergroup0.html", [
      [ "KUNBUS GmbH", "^http://www.kunbus.com", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"abbreviations.html",
"group___ci_a402_gaa715777f009618cbb8f3236f9507637f.html#gaa715777f009618cbb8f3236f9507637f",
"group___e_c___a_p_i___s_l_v___ci_a402_gaade9018883f0c83892829d164f9144d0.html#gaade9018883f0c83892829d164f9144d0",
"group___sdo_types_ga042f45497434e3a99669e82b2775482b.html#ga042f45497434e3a99669e82b2775482b",
"struct_e_c___s_l_v___a_p_p___sapplication_a8f0ace010210b60edb96478c346f5a69.html#a8f0ace010210b60edb96478c346f5a69"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
